@@ -7,6 +7,13 @@
 #include <QtGui/QCloseEvent>
 #include <QSettings>
 #include <QDebug>
+#include <QFileDialog>
+
+//check your last post. Also exc and wer. Think it might be problems relating to writing to .tmpvid. Running stream on root priveleges might solve it, but I dont want toresort to that yet.
+//File: Working: Yoooutube.mp4, Y.Tu.mama.avi, USAbit.avi,   La Luna.avi, vids taken by camera (slowly for large vids).
+//Not: Yeah Yeah.mp4, U2.mp4, The Tron Rap.mp4, Gorrilaz, The dreamers.AVI?, the Matrix.avi,
+//VLC now working, but I had to delete my cache and config. Kind of works.
+//Old VLC method seems to work.
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -46,53 +53,63 @@ MainWindow::~MainWindow()
     delete ui;
 }
 
-
 void MainWindow::makeStream(QString host, bool backcamera, bool video, QString port, QString width, QString height, int outp){
     QString contextRun;
+    QString begbits;
     QString midbits;
     QString streamout;
     QString qbcam;
     QString Jquality;
+    qDebug() << "making stream";
+
     if(ui->tickqual->isChecked()){Jquality= "quality="+ui->qcontrol->text();}else{Jquality="";}   //necessary because the option kills quality, even if 100%
     if(video){
         if(backcamera){ qbcam = "0"; } else { qbcam = "1";}
-        if(outp==3){ //filesink
+        if(fileyes){
+            begbits ="filesrc location="+openfile+" ! decodebin !";
+        } else if(!fileyes) {
+            begbits="v4l2src device=/dev/video"+qbcam+" ! videoscale ! video/x-raw-yuv,width="+width+",height="+height+" ! ";
+        }
+        if(outp==4){ //filesink
             QString filelocation = ui->filesinkname->text();
             streamout = "gst-launch-0.10 v4l2src device=/dev/video"+qbcam+" ! videoscale ! video/x-raw-yuv,width="+width+",height="+height+" ! ffmpegcolorspace ! jpegenc "+Jquality+" ! avimux ! filesink location=/home/user/MyDocs/.videos/"+filelocation+".avi";
             notify("streaming to "+filelocation, false);
         }
-        else if(outp==0){//VLC  //dont forget to delete file
-            write2file("/home/user/.httpstream", "#!/bin/bash\nread throwaway\nsleep 5\necho HTTP/1.0 200 Ok\necho Server: socat kludge\necho -n Date:\ndate\necho Content-Type: video/x-msvideo\necho Content-Length: 10000000\necho Last-Modified: Sun, 19 Jun 2011 22:53:20 GMT\necho Connection: close\necho\nrm -f /home/user/.tmpvid 2>/dev/null\nmkfifo /home/user/.tmpvid\ngst-launch v4l2src device=/dev/video"+qbcam+" ! videoscale ! video/x-raw-yuv,width="+width+",height="+height+" ! ffmpegcolorspace ! jpegenc "+Jquality+" ! filesink location=/home/user/.tmpvid >/dev/null &\ncat /home/user/.tmpvid");
+        else if(outp==0){//http  //dont forget to delete file
+            QString exc = "#!/bin/bash\nread throwaway\nsleep 5\necho HTTP/1.0 200 Ok\necho Server: socat kludge\necho -n Date:\ndate\necho Content-Type: video/x-msvideo\necho Content-Length: 10000000\necho Last-Modified: Sun, 19 Jun 2011 22:53:20 GMT\necho Connection: close\necho\nrm -f /home/user/.tmpvid > /dev/null\nmkfifo /home/user/.tmpvid\ngst-launch-0.10vlc  "+begbits+"ffmpegcolorspace ! jpegenc"+Jquality+" ! filesink location=/home/user/.tmpvid >/dev/null &\ncat /home/user/.tmpvid";
+            //QString wer = "#!/bin/bash\nread throwaway\nsleep 5\necho HTTP/1.0 200 Ok\necho Server: socat kludge\necho -n Date:\ndate\necho Content-Type: video/x-msvideo\necho Content-Length: 10000000\necho Last-Modified: Sun, 19 Jun 2011 22:53:20 GMT\necho Connection: close\necho\nrm -f /home/user/.tmmm >/dev/null\nmkfifo /home/user/.tmmm\ngst-launch "+begbits+" ffmpegcolorspace ! jpegenc "+Jquality+" ! filesink location=/home/user/.tmmm >/dev/null &\ncat /home/user/.tmmm";
+            write2file("/home/user/.httpstream", exc);
             executable("/home/user/.httpstream");
-            streamout = "socat TCP4-LISTEN:"+port+",reuseaddr,fork exec:/home/user/.httpstream",
+            qDebug() << exc;
+            streamout = "socat TCP4-LISTEN:"+port+",reuseaddr,fork exec:/home/user/.httpstream";
             notify("Open VLC:\nMedia-->Open Network Stream..., Type in:\nhttp://"+getIP()+":"+port, true);
             notify("streaming", false);
         }
 
-        else if(outp!=0 || outp!=3){ //VLC or filesink? no   //this is neccasary because vlc and localfile dont streamout normally
-            if (outp==1){ //Xout
+        else if(outp!=0 || outp!=4){ //http or filesink? no   //this is neccasary because http and localfile dont streamout normally
+            if(outp==1){ //VLC
+                midbits = "dsph264enc ! rtph264pay ! udpsink";
+                contextRun = "   Open n900mediastrm.sdp file in VLC";
+            } else if (outp==2){ //Xout
                 midbits = "ffmpegcolorspace ! jpegenc "+Jquality+" ! tcpserversink";
                 contextRun = "   from terminal, run: 'sh ~/Desktop/n900Xvideo.sh'";
-            } else if (outp==2){//webcam
+            } else if (outp==3){//webcam
                 //midbits = "ffmpegcolorspace ! smokeenc ! udpsink";  using jpeg for quality preferences.
                 midbits = "ffmpegcolorspace ! jpegenc "+Jquality+" ! tcpserversink";
                 contextRun = "   from terminal, run: 'sh ~/Desktop/n900Webvideo.sh'";
-            } else if (outp==4){ //remote file
+            } else if (outp==5){ //remote file
                 midbits = "ffmpegcolorspace ! jpegenc "+Jquality+" ! tcpserversink";
                 contextRun = "   from terminal, run: 'sh ~/Desktop/n900FileSave.sh'\n(Make sure that 'gstreamer0.10-ffmpeg' is installed on remote PC)";
             }
-            streamout = "gst-launch-0.10 v4l2src device=/dev/video"+qbcam+" ! videoscale ! video/x-raw-yuv,width="+width+",height="+height+" !"+midbits+" host="+host+" port="+port;
+            streamout = "gst-launch-0.10 "+begbits+midbits+" host="+host+" port="+port;
             notify("Run file on Remote PC: \n"+contextRun, true);
             //more contextual instruction o how to run the file needed.
             notify("streaming", false);
+
         }
-        ui->outWind->setText("...currently streaming...");
-        QProcess*proc = new QProcess();
-        proc->start(streamout);
-        //ui->outWind->append(proc->readAll()); //NOW JUST NEED TO PASS OUTPUT FROM GST-LAUNCH BACK INTO OUTWIND
     }
     else if (!video){
-        streamout = " ";
+        streamout = "gst-launch-0.10 pulsesrc ! audioconvert ! volume volume="+ui->vol->text()+" ! audioresample ! nokiaaacenc ! rtpmp4apay ! udpsink host="+host+" port="+port;
         /*QString stream1 = "gst-launch-0.10 pulsesrc ! audioconvert ! volume volume="+ui->vol->text()+" ! audioresample ! nokiaaacenc ! rtpmp4apay";
         write2file("/home/user/.httpstream", "#!/bin/bash\nread throwaway\nsleep 7\necho HTTP/1.0 200 Ok\necho Server: socat kludge\necho -n Date:\ndate\necho Content-Type: audio/mpeg\necho Content-Length: 10000000\necho Last-Modified: Sun, 19 Jun 2011 22:53:20 GMT\necho Connection: close\necho\nrm -f /home/user/.tmpvid 2>/dev/null\nmkfifo /home/user/.tmpvid\n"+stream1+" ! filesink location=/home/user/.tmpvid >/dev/null &\ncat /home/user/.tmpvid");
         executable("/home/user/.httpstream");
@@ -100,40 +117,44 @@ void MainWindow::makeStream(QString host, bool backcamera, bool video, QString p
         notify("Open VLC:\nMedia-->Open Network Stream..., Type in:\nhttp://"+getIP()+":"+port, true);
         notify("streaming", false);*/
 
-    }   
+    }
+    ui->outWind->setText("...currently streaming...");
+    QProcess*proc = new QProcess();
+    qDebug() << streamout;
+    proc->start(streamout);
+    //ui->outWind->append(proc->readAll()); //NOW JUST NEED TO PASS OUTPUT FROM GST-LAUNCH BACK INTO OUTWIND
  }
 
 void MainWindow::write2file(QString path, QString script){
     //writing bash script
     QFile file(path);
-    file.open(QIODevice::WriteOnly | QIODevice::Text);
+    file.open(QIODevice::ReadWrite | QIODevice::Text);
     QTextStream out(&file);
     out << script;
     file.close();
     //ui->outWind->append("Generated");
 
 }
+
 void MainWindow::executable(QString path){ //wish there was a way to preserve permissions over scp...
     QStringList args;
-    args << "-c" << "sudo chmod a+x "+path;
+    args << "-c" << QString("echo %1chmod a+wrx "+path+"%1 | root").arg(QChar(0x22));
     QProcess* exer = new QProcess(this);
     exer->start("/bin/sh", args);
     exer->waitForFinished();
     exer->terminate();
 }
 
-
-
 void MainWindow::on_streambut_clicked()
 {
     int cind = ui->vidsink->currentIndex();
-    if(ui->filesinkname->text()=="" && (cind==3 || cind==4)){ //if filesink and blank
+    if(ui->filesinkname->text()=="" && (cind==4 || cind==5)){ //if filesink and blank
         notify("Fill out filename first", false);
     }
     else{
-        if((cind!=0 )&& (!alreadygen.contains(ui->vidsink->currentText()+" "+ui->address1->text()+":"+ui->port1->text()))){   //if not VLC or file hasnt been generated previously, then flag.
+        if((cind!=0 )&& (!alreadygen.contains(ui->vidsink->currentText()+" "+ui->address1->text()+":"+ui->port1->text()))){   //if not http or file hasnt been generated previously, then flag.
             sdpgenerated = false;
-            if(ui->type1->currentIndex()!=1 && cind!=3){ //if not audio and not filesink
+            if(ui->type1->currentIndex()!=1 && cind!=4){ //if not audio and not filesink
                 notify("Please generate and send a new file, then stream", false);
             }
             else { //local file streams
@@ -165,15 +186,14 @@ void MainWindow::helper(){
     }
 }
 
-
-
 void MainWindow::writeSettings(){
     QSettings settings("daUser", "tester");
     settings.beginGroup("MainWindow"); //beginWriteArray?
     settings.setValue("address",ui->address1->text());settings.setValue("port",ui->port1->text());
     settings.setValue("type",ui->type1->currentIndex()); settings.setValue("camera",ui->camera1->currentIndex()); settings.setValue("size",ui->size1->currentIndex());
     settings.setValue("custom",ui->custom1->text()); settings.setValue("user",ui->usernam->text());settings.setValue("volume", ui->vol->text()); settings.setValue("quality",ui->qcontrol->text());
-    settings.setValue("checked",ui->rempass->checkState());
+    settings.setValue("checked",ui->rempass->checkState()); settings.setValue("OpenPath", openpath);
+
     if(ui->rempass->isChecked()){
         settings.setValue("password",ui->passwrd->text());
     } else{
@@ -182,16 +202,16 @@ void MainWindow::writeSettings(){
     settings.endGroup();
 }
 
-
 void MainWindow::applySettings(){
     QSettings settings("daUser", "tester");
     settings.beginGroup("MainWindow");
+    if(openpath.length()<5){openpath="/home/user/MyDocs";}else{openpath=settings.value("Openpath").toString();}
     ui->address1->setText(settings.value("address").toString()); ui->port1->setText(settings.value("port").toString()); ui->type1->setCurrentIndex(settings.value("type").toInt());
-    ui->size1->setCurrentIndex(settings.value("size").toInt()); ui->camera1->setCurrentIndex(settings.value("camera").toInt());
+    ui->size1->setCurrentIndex(settings.value("size").toInt());
+    int camsrc = settings.value("camera").toInt(); if(camsrc==2){ui->camera1->setCurrentIndex(1);}else{ui->camera1->setCurrentIndex(camsrc);} //stops it from opening filedialog on entry.
     ui->custom1->setText(settings.value("custom").toString());ui->usernam->setText(settings.value("user").toString()); ui->passwrd->setText(settings.value("password").toString());
     volumeR = settings.value("volume").toString(); ui->vol->setText(volumeR); ui->qcontrol->setText(settings.value("quality").toString());
     if(ui->type1->currentIndex()==1){on_type1_activated(1);} else {on_type1_activated(0);}
-
     if(settings.value("checked")==(Qt::Checked)){ui->rempass->setCheckState(Qt::Checked);} else {ui->rempass->setCheckState(Qt::Unchecked);}
     settings.endGroup();
 }
@@ -214,7 +234,7 @@ void MainWindow::streamProcess1(){
         heightnum = sized[1];
         int currOutput = ui->vidsink->currentIndex();
         //LED
-        ledON(true);
+        if(!fileyes)ledON(true);
 
         makeStream(hostname,cambackyes,videoyes,portnum,widthnum,heightnum, currOutput);
     }
@@ -230,8 +250,6 @@ void MainWindow::showWin(bool hid){
     ui->tickqual->setProperty("enabled",hid);ui->qcontrol->setProperty("enabled",hid); ui->filesinkname->setProperty("enabled",hid);
 }
 
-
-
 void MainWindow::scpSender(QString user, QString pass, QString file){
     QString expectfile = QString("#!/usr/bin/expect -f\nset filename [lindex $argv 0]\nset user [lindex $argv 1]\nset pass [lindex $argv 2]\nset ipadd [lindex $argv 3]\nset timeout -1\nspawn scp $filename $user@$ipadd:/home/$user/Desktop\nexpect {\n%1yes/no)?%1 {exp_send %1yes%2r%1; exp_continue}\n%1*assword:%1 { send %1$pass%2r%1; exp_continue}\neof exit\n}").arg(QChar(0x22),QChar(0x5c));
     write2file("/home/user/.scp",expectfile);
@@ -325,7 +343,6 @@ void MainWindow::scpSender(QString user, QString pass, QString file){
     sender1->terminate();
 }
 
-
 void MainWindow::notify(QString message, bool bottortop){  //for doing notifications to phone
     QProcess*warn1 = new QProcess();
     QString messy="";
@@ -340,7 +357,6 @@ void MainWindow::notify(QString message, bool bottortop){  //for doing notificat
     warn1->terminate();
 }
 
-
 void MainWindow::on_type1_activated(int index) //link on cmera1_activated into this? and then link size_activate into camera1_actiavet?!?!
 {
     //Show Addres
@@ -388,17 +404,33 @@ void MainWindow::on_type1_activated(int index) //link on cmera1_activated into t
 
 void MainWindow::on_camera1_activated(int index)
 {
-    if(index==1){
-        cambackyes = false;
-        if(ui->size1->itemText(0)=="640x480"){
-            ui->size1->removeItem(0);
+    if(index==1 || index==0){
+        fileyes = false;
+        ui->size1->show();
+        ui->labsize->show();
+        if(index==1){
+            cambackyes = false;
+            if(ui->size1->itemText(0)=="640x480"){
+                ui->size1->removeItem(0);
+            }
+        }
+        else if(index==0){
+            cambackyes = true;
+            if(ui->size1->itemText(0)!="640x480"){
+                ui->size1->insertItem(0,"640x480");
+            }
         }
     }
-    else {
-        cambackyes = true;
-        if(ui->size1->itemText(0)!="640x480"){
-            ui->size1->insertItem(0,"640x480");
-        }
+    else{ //File
+        fileyes = true;
+        ui->size1->hide();
+        ui->labsize->hide();
+        if(openpath=="."){openpath="/home/user/MyDocs";}
+        QString pather = QFileDialog::getOpenFileName(this, tr("Open File for Streaming"),openpath, tr("Music (*.mp3 *.wav *.wma);;Video (*.avi *.mpg *.mp4 *.mpeg)"));
+        QString dir = QFileInfo(pather).path();
+        openpath = dir;
+        openfile = QFileInfo(pather).absoluteFilePath();
+        qDebug()<<openfile+" "+dir;
     }
 }
 
@@ -432,12 +464,13 @@ void MainWindow::on_debuginfo_clicked()
 
 QString MainWindow::getIP(){
     QStringList arguments1;
-    arguments1 << "-c" << "sudo ifconfig  | grep 'inet addr:'| grep -v '127.0.0.1' | cut -d: -f2 | awk '{ print $1}'";
+    arguments1 << "-c" << QString("echo %1ifconfig | grep 'inet addr:'| grep -v '127.0.0.1' | cut -d: -f2 | awk '{ print $1}'%1 | root").arg(QChar(0x22));
     QProcess*process1 = new QProcess(this);
     process1->start("/bin/sh", arguments1);
     process1->waitForFinished();
     QString tmp = process1->readAll();
     tmp = tmp.split(QRegExp("\\s+")).at(0); //removes spaces at end
+    qDebug() << tmp;
     return tmp;
 
 }
@@ -447,19 +480,26 @@ void MainWindow::on_sdpgen_clicked()
     //sdpyes = false;
     QString localip=getIP();
     ui->outWind->setText("Local IP is "+localip);
-    //QString decoder;QString typer;
+    QString decoder;QString typer;
     int outpp = ui->vidsink->currentIndex();
 
-    if(outpp==0){ //VLC   <------Needs hiding
-        notify("Don't need to generate anything for VLC", false);
+    if(outpp==0){ //VLC Http   <------Needs hiding
+        notify("Don't need to generate anything for this", false);
         ui->outWind->clear();
     }
-    else if(outpp==1) { //Xout
+    else if(outpp==1){ //VLC old
+        if(videoyes){ typer = "video"; decoder ="H264/90000";}
+        else if(!videoyes){ typer="audio"; decoder="MP4A-LATM/48000/2";}
+        currentFile ="/home/user/MyDocs/n900"+typer+"strm.sdp";
+        write2file(currentFile,"v=0\nm="+typer+" "+ui->port1->text()+" RTP/AVP 96\nc=IN IP4 "+localip+"\na=rtpmap:96 "+decoder); //VLC
+    }
+
+    else if(outpp==2) { //Xout
         currentFile = "/home/user/MyDocs/n900Xvideo.sh";
         write2file(currentFile,"gst-launch-0.10 tcpclientsrc host="+localip+" port="+ui->port1->text()+"  ! jpegdec ! autovideosink"); //Xout
         ui->outWind->append("Generated file at: "+currentFile);
     }
-    else if(outpp==2) { //webcam
+    else if(outpp==3) { //webcam
         currentFile = "/home/user/MyDocs/n900Webvideo.sh";
         //write2file(currentFile,"gst-launch-0.10 udpsrc port="+ui->port1->text()+" ! smokedec ! ffmpegcolorspace ! v4l2loopback device=/dev/video0");  //webcam
         //Using Jpeg for now, higer quality?
@@ -467,12 +507,12 @@ void MainWindow::on_sdpgen_clicked()
         ui->outWind->append("Generated file at: "+currentFile);
 
     }
-    else if(outpp==3) {//filesink --generate button hidden for this, but just in case.
+    else if(outpp==4) {//filesink --generate button hidden for this, but just in case.
         notify("Don't need to generate anything for local file", false);
         ui->outWind->clear();
 
     }
-    else if(outpp==4){//remote filesink
+    else if(outpp==5){//remote filesink
         currentFile = "/home/user/MyDocs/n900FileSave.sh";
         write2file(currentFile,"gst-launch-0.10 tcpclientsrc host="+localip+" port="+ui->port1->text()+" ! jpegdec ! ffenc_mpeg2video ! filesink location=/home/"+ui->usernam->text()+"/Desktop/"+ui->filesinkname->text()+".mpg");
         ui->outWind->append("Generated file at: "+currentFile);
@@ -545,7 +585,6 @@ void MainWindow::on_scpbutton_clicked()
 void MainWindow::on_scpsend_clicked()
 {
     alreadygen.append(ui->vidsink->currentText()+" "+ui->address1->text()+":"+ui->port1->text()); //adds generated selection to list.
-    //qDebug() << alreadygen;
     ui->scpsend->setStyleSheet("QPushButton {background-color : rgb(60, 60, 100); color : white;}");
     ui->scpframe->hide();
     //showWin(false);
@@ -556,11 +595,14 @@ void MainWindow::on_scpsend_clicked()
 
 void MainWindow::on_vidsink_activated(int index)  //First part is for showing the filename widgets
 {
-    if(index==3 || index==4){//File
+    if(ui->camera1->itemText(2)!="File"){
+        ui->camera1->addItem("File");
+    }
+    if(index==4 || index==5){//File
         ui->labfilenam->show();
         ui->filesinkname->show();
         ui->tickqual->show();
-        if(index==3){ //local
+        if(index==4){ //local
             ui->sdpgen->hide();
             ui->scpbutton->hide();
             ui->labfilenam->setText("     Filename (/home/user/MyDocs/.videos/):");
@@ -568,9 +610,10 @@ void MainWindow::on_vidsink_activated(int index)  //First part is for showing th
             ui->address1->hide(); ui->labAddr->hide(); ui->port1->hide(); ui->labPort->hide();
             ui->outWind->setText("Nothing needed to generate or send. \nPlease fill out name of video and hit Stream.");
             sdpgenerated = true; //doesnt need to generate one.
-
+            ui->camera1->removeItem(2); //<=========== Doesn't use file as source.////////
+            ui->labsize->show(); ui->size1->show();
         }
-        if(index==4) {
+        if(index==5) {
             if(debugclicked){ui->sdpgen->show();}  //error when switching from local file to remote file.
             ui->labfilenam->setText("    Remote Filename:");
             vidoutput="RemoteFilescript";
@@ -578,7 +621,7 @@ void MainWindow::on_vidsink_activated(int index)  //First part is for showing th
             ui->outWind->setText("Fill out filename and then generate");
         }
 
-    } else if(index!=3 || index!=4){
+    } else if(index!=4 || index!=5){
 
         ui->address1->show(); ui->labAddr->show(); ui->port1->show(); ui->labPort->show();
         ui->labfilenam->hide();
@@ -592,8 +635,9 @@ void MainWindow::on_vidsink_activated(int index)  //First part is for showing th
         } else {
             ui->outWind->setText("Please generate and send");
             ui->tickqual->show();
-            if(index==1){vidoutput = "Xscript";}
-            if(index==2){vidoutput="Webscript";}
+            if(index==1){vidoutput = "VLC sdp";}
+            if(index==2){vidoutput = "Xscript";}
+            if(index==3){vidoutput="Webscript";}
         }
     }
     ui->sdpgen->setText("Generate "+vidoutput+" file");
