@@ -35,6 +35,9 @@ private:
     QString volumeR;
     bool debugclicked;
     QStringList alreadygen;
+    QString openpath;
+    QString openfile;
+    bool fileyes; //using filesource.
 
 private slots:
     void on_tickqual_toggled(bool checked);
